@@ -22,7 +22,7 @@
 (defn fact-names-app
   [version]
   (case version
-    :v1 (throw (IllegalArgumentException. "fact-names endpoint not availabe for v1 API"))
+    :v1 (throw (IllegalArgumentException. "api v1 is retired"))
     :v2 (-> routes
           verify-accepts-json
           (validate-no-query-params))
