@@ -34,7 +34,6 @@
             [com.puppetlabs.puppetdb.scf.storage-utils :as sutils]
             [com.puppetlabs.puppetdb.scf.hash-debug :as hashdbg]
             [schema.core :as s]
-            [schema.macros :as sm]
             [com.puppetlabs.puppetdb.schema :as pls :refer [defn-validated]]
             [com.puppetlabs.puppetdb.utils :as utils]
             [clj-time.coerce :refer [to-timestamp]]
@@ -471,7 +470,7 @@
     (doseq [{:keys [type title]} refs-to-delete]
       (sql/delete-rows :catalog_resources ["catalog_id = ? and type = ? and title = ?" catalog-id type title]))))
 
-(sm/defn basic-diff
+(s/defn basic-diff
   "Basic diffing that returns only the keys/values of `right` whose values don't match those of `left`.
    This is different from clojure.data/diff in that it treats non-equal sets as completely different
    (rather than returning only the differing items of the set) and only returns differences from `right`."
@@ -483,7 +482,7 @@
                    (assoc acc k right-value))))
              {} right))
 
-(sm/defn diff-resources-metadata
+(s/defn diff-resources-metadata
   "Return resource references with values that are only the key/values that from `right` that
    are different from those of the `left`. The keys/values here are suitable for issuing update
    statements that will update resources to the correct (new) values."
@@ -780,11 +779,9 @@
   [factset-id removed-pid-vid-pairs]
   (when-let [removed-pid-vid-pairs (seq removed-pid-vid-pairs)]
     (let [vids (map second removed-pid-vid-pairs)
-          fp-id-pairs (map vector
-                           (repeat factset-id )
-                           (map first removed-pid-vid-pairs))
+          rm-facts (map cons (repeat factset-id) removed-pid-vid-pairs)
           in-vids (jdbc/in-clause vids)
-          in-fp-id-pairs (jdbc/in-clause-multi fp-id-pairs 2)]
+          in-rm-facts (jdbc/in-clause-multi rm-facts 3)]
       (sql/do-prepared
        (format
         "DELETE FROM fact_values fv
@@ -792,9 +789,11 @@
              AND NOT EXISTS (SELECT 1 FROM facts f
                                WHERE f.fact_value_id %s
                                  AND f.fact_value_id = fv.id
-                                 AND (f.factset_id, f.fact_path_id) NOT %s)"
-        in-vids in-vids in-fp-id-pairs)
-       (flatten [vids vids fp-id-pairs])))))
+                                 AND (f.factset_id,
+                                      f.fact_path_id,
+                                      f.fact_value_id) NOT %s)"
+        in-vids in-vids in-rm-facts)
+       (flatten [vids vids rm-facts])))))
 
 (defn-validated delete-orphaned-paths! :- s/Int
   "Deletes up to n paths that are no longer mentioned by any factsets,
